# Table of Contents

- [sap-leanix-applications-terms-and-conditions-microsoft-teams](<./sap-leanix-applications-terms-and-conditions-microsoft-teams.md>)
- [SAP LeanIX](<./SAP-LeanIX.md>)
- [SAP LeanIX Applications Terms and Conditions (Microsoft Teams)](<./SAP-LeanIX-Applications-Terms-and-Conditions-Microsoft-Teams.md>)
  - [Provision of the Application](<./SAP-LeanIX-Applications-Terms-and-Conditions-Microsoft-Teams/Provision-of-the-Application.md>)
  - [LeanIX Terms](<./SAP-LeanIX-Applications-Terms-and-Conditions-Microsoft-Teams/LeanIX-Terms.md>)
  - [Data](<./SAP-LeanIX-Applications-Terms-and-Conditions-Microsoft-Teams/Data.md>)
  - [Disclaimer](<./SAP-LeanIX-Applications-Terms-and-Conditions-Microsoft-Teams/Disclaimer.md>)
  - [Limitations of Liability](<./SAP-LeanIX-Applications-Terms-and-Conditions-Microsoft-Teams/Limitations-of-Liability.md>)
  - [Miscellaneous](<./SAP-LeanIX-Applications-Terms-and-Conditions-Microsoft-Teams/Miscellaneous.md>)
  - [Was this page helpful?](<./SAP-LeanIX-Applications-Terms-and-Conditions-Microsoft-Teams/Was-this-page-helpful.md>)
